import React, { useState, useEffect } from 'react';
import { Space, Table, Button, Divider, Card } from 'antd';
import type { TableColumnsType } from 'antd';
import { t } from '@/utils/i18n';
import { PlusOutlined, ExclamationCircleFilled } from '@ant-design/icons';
import { antdUtils } from '@/utils/antd';
import { useRequest } from '@/hooks/use-request';
import { formatDate } from '@/utils/formatTime'
import dataSourceService from '@/request/service/data-source';
import { DataSourceConfigVO } from '@/models';
import DataSourceConfigEditor from './data-source-config-editor';

export default () => {

    const [editorVisable, seEditorVisable] = useState<boolean>(false);
    const [editNotice, setEditNotice] = useState<DataSourceConfigVO>();
    const [dataSource, setDataSource] = useState<DataSourceConfigVO[]>([]);

    const { runAsync: getListData } = useRequest(dataSourceService.getDataSourceConfigListApi, { manual: true });
    const { runAsync: deleteItem } = useRequest(dataSourceService.deleteDataSourceConfigApi, { manual: true });

    const load = async () => {
        const [error, { code, msg, data }] = await getListData();
        if (error || code !== 0) {
            antdUtils.message?.open({ type: 'error', content: msg ?? '操作失败' });
            return
        }
        setDataSource(data);
    };

    const showDeleteConfirm = (role: DataSourceConfigVO) => {
        antdUtils.modal?.confirm({
            title: '确认要将该通知删除吗？',
            icon: <ExclamationCircleFilled />,
            content: '请注意删除以后不可恢复！',
            okText: '删除',
            okType: 'danger',
            cancelText: '取消',
            onOk() {
                return new Promise(async (resolve) => {
                    const [error, { code, msg }] = await deleteItem(role.id);
                    if (error || code !== 0) {
                        antdUtils.message?.open({ type: 'error', content: msg ?? '操作失败' })
                    } else {
                        antdUtils.message?.open({ type: 'success', content: '删除成功' })
                    }
                    await load();
                    resolve('')
                }).catch(() => antdUtils.message?.open({
                    type: 'error',
                    content: '操作失败',
                }));
            },
            onCancel() {
            },
        });
    };

    const columns: TableColumnsType<DataSourceConfigVO> = [
        {
            title: '序号',
            dataIndex: 'id',
            key: 'id',
            align: 'center',
            width: 100,
        },
        {
            title: '数据源名称',
            dataIndex: 'name',
            key: 'name',
            filterSearch: true,
            align: 'center',
            width: 200,
        },
        {
            title: '数据源连接',
            dataIndex: 'url',
            key: 'url',
            align: 'center',
        },
        {
            title: '用户名',
            key: 'username',
            dataIndex: 'username',
            width: 150,
            align: 'center'
        },
        {
            title: '创建时间',
            key: 'createTime',
            dataIndex: 'createTime',
            width: 200,
            align: 'center',
            render: (value: number) => {
                return formatDate(new Date(value), "YYYY-mm-dd HH:MM:SS")
            }
        },
        {
            title: t("QkOmYwne" /* 操作 */),
            key: 'action',
            fixed: 'right',
            align: 'center',
            width: 200,
            render: (value: DataSourceConfigVO, record) => (
                <Space size="small" split={(<Divider type='vertical' />)}>
                    <a onClick={() => {
                        setEditNotice(value);
                        seEditorVisable(true);
                    }}>
                        编辑
                    </a>
                    <a onClick={() => {

                    }}>
                        详情
                    </a>
                    <a onClick={() => {
                        showDeleteConfirm(value);
                    }}>
                        删除
                    </a>
                </Space>
            ),
        },
    ];

    useEffect(() => {
        load();
    }, []);

    return (
        <>
            <div>
                <Card className='mt-[4px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]'
                    bodyStyle={{
                        paddingTop: 0,
                        paddingBottom: 0
                    }}>
                    <div className='flex justify-end content-center'>
                        <div className="py-[4px] flex justify-normal items-center">
                            <Button className="ml-5" type='primary' size='large' icon={<PlusOutlined />} onClick={() => {
                                setEditNotice(undefined);
                                seEditorVisable(true);
                            }}> 新增 </Button>
                        </div>
                    </div>
                    <Table rowKey="id"
                        scroll={{ x: true }}
                        columns={columns}

                        dataSource={dataSource}
                        className='bg-transparent'
                        pagination={false}/>
                </Card>
            </div>
            <DataSourceConfigEditor
                onSave={() => {
                    load();
                    seEditorVisable(false);
                }}
                onCancel={() => { seEditorVisable(false) }}
                visible={editorVisable}
                data={editNotice} />
        </>
    );
};
