import React, { useEffect, useState } from 'react'
import { Form, Input, Radio, Modal, InputNumber, ColorPicker } from 'antd';
import dictDataService from '@/request/service/system-dictdata';
import { useRequest } from '@/hooks/use-request';
import type { DictDataVO } from '@/models'
import { antdUtils } from '@/utils/antd';


const layout = {
    labelCol: { span: 4, },
    wrapperCol: { span: 16 }
};

interface DataTypeEditorProps {
    visible: boolean;
    onCancel: (flag?: boolean) => void;
    onSave: (role: DictDataVO) => void;
    data?: DictDataVO | null;
    dictType: string;
}

export default (props: DataTypeEditorProps) => {

    const { visible, onCancel, onSave, data, dictType } = props;
    const { runAsync: update } = useRequest(dictDataService.updateDictDataApi, { manual: true });
    const { runAsync: create } = useRequest(dictDataService.createDictDataApi, { manual: true });

    const isEdit = !!data;


    const [saveLoading, setSaveLoading] = useState(false);
    const [form] = Form.useForm();

    useEffect(() => {
        if (visible) {
            if (data) {
                form.setFieldsValue(data);
            }
            form.setFieldValue('dictType', dictType);
        } else {
            form.resetFields();
        }
    }, [visible]);

    const save = async () => {
        setSaveLoading(true);
        const fieldValues = form.getFieldsValue();
        const cssClass = fieldValues.cssClass ? fieldValues.cssClass.toHex() : '';
        const newValue = isEdit ? { ...data, ...fieldValues, cssClass } : fieldValues;
        const [error, { msg, code }] = isEdit ? await update(newValue) : await create(newValue);
        if (!error && code === 0) {
            onSave(newValue);
        } else {
            antdUtils.message?.open({
                type: 'error',
                content: msg ?? '操作失败',
            });
        }
        setSaveLoading(false);
    }

    return (
        <>
            <Modal
                open={visible}
                title={isEdit ? "编辑" : "新建"}
                width={640}
                onOk={save}
                onCancel={() => onCancel()}
                confirmLoading={saveLoading}
                destroyOnClose
            >
                <Form
                    form={form}
                    {...layout}
                    onFinish={save}
                    labelCol={{ flex: '0 0 100px' }}
                    wrapperCol={{ span: 16 }}
                >
                    <Form.Item name="dictType" label="字典类型">
                        <Input value={dictType} disabled={true} />
                    </Form.Item>
                    <Form.Item name="label" label="数据标签"
                        rules={[
                            {
                                required: true,
                                message: '请输入数据标签',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>

                    <Form.Item name="value" label="数据键值"
                        rules={[
                            {
                                required: true,
                                message: '请输入数据键值',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>

                    <Form.Item name="sort" label="显示排序"
                        rules={[
                            {
                                required: true,
                                message: '请输入显示排序',
                            },
                        ]}>
                        <InputNumber min={0} />
                    </Form.Item>

                    <Form.Item
                        name="cssClass"
                        label="颜色"
                    >
                        <ColorPicker format="hex"/>
                    </Form.Item>

                    <Form.Item name="status" label="状态">
                        <Radio.Group options={[
                            { value: 0, label: "开启" },
                            { value: 1, label: "关闭" }
                        ]} optionType="default">
                        </Radio.Group>
                    </Form.Item>

                    <Form.Item name="remark" label="备注" >
                        <Input.TextArea showCount maxLength={100} />
                    </Form.Item>
                </Form>
            </Modal>
        </>
    )
};
