import React, { useState, useEffect, useRef } from 'react';
import { useSetState } from 'ahooks';
import { Space, Table, Button, Input, FloatButton, Divider, Tag, Card, Tooltip } from 'antd';
import type { TableColumnsType, InputRef } from 'antd';
import type { ColumnType, TableProps } from 'antd/es/table';
import { t } from '@/utils/i18n';
import { DownloadOutlined , SearchOutlined } from '@ant-design/icons';
import { antdUtils } from '@/utils/antd';
import { useRequest } from '@/hooks/use-request';
import { formatDate } from '@/utils/formatTime'
import logsService from '@/request/service/logs';
import { LoginLogVO, LoginLogReqVO } from '@/models';


type DataIndex = keyof LoginLogVO;

const mapOperation = (operation: number) => {
    if (operation === 1) {
        return (<Tag color="purple">通知</Tag>)
    } else if (operation === 2) {
        return (<Tag color="purple">新增</Tag>)
    } else if (operation === 3) {
        return (<Tag color="blue">修改</Tag>)
    } else if (operation === 4) {
        return (<Tag color="red">删除</Tag>)
    } else {
        return (<Tag color="red">未知({operation})</Tag>)
    }
}

export default () => {
    const [dataSource, setDataSource] = useState<LoginLogVO[]>([]);

    const { runAsync: getPageData } = useRequest(logsService.getLoginLogPageApi, { manual: true });

    const [searchState, setSearchState] = useSetState<LoginLogReqVO>({
        pageNo: 1,
        pageSize: 10
    });
    const [total, setTotal] = useState(0)
    const searchInput = useRef<InputRef>(null);
    const [onSearching, setOnSearching] = useState(false);

    const load = async () => {
        console.log(searchState)
        const [error, { code, msg, data }] = await getPageData(searchState);
        setOnSearching(false);
        if (error || code !== 0) {
            antdUtils.message?.open({ type: 'error', content: msg ?? '操作失败' });
            return
        }
        setTotal(data.total);
        setDataSource(data.list);
    };

    const getColumnSearchProps = (dataIndex: DataIndex): ColumnType<LoginLogVO> => ({
        filterDropdown: ({ setSelectedKeys, selectedKeys, confirm, clearFilters, close }) => (
            <div style={{ padding: 8 }} onKeyDown={(e) => e.stopPropagation()}>
                <Input.Search
                    ref={searchInput}
                    placeholder={"输入公告标题"}
                    value={selectedKeys[0]}
                    onChange={(e) => {
                        setSelectedKeys(e.target.value && e.target.value !== '' ? [e.target.value] : [])
                    }}
                    onSearch={(value) => {
                        if (value === '' && clearFilters) {
                            clearFilters!!()
                        }
                        confirm();
                    }}
                    onPressEnter={() => confirm()}
                    allowClear
                    style={{ marginBottom: 8, display: 'block' }}
                    enterButton="搜索"
                    size="middle"
                    loading={onSearching}
                />
            </div>
        ),
        filterIcon: (filtered: boolean) => (
            <SearchOutlined style={{ color: filtered ? 'primaryColor' : undefined }} />
        ),
        onFilterDropdownOpenChange: (visible) => {
            if (visible) {
                setTimeout(() => searchInput.current?.select(), 100);
            }
        },
    });

    const columns: TableColumnsType<LoginLogVO> = [
        {
            title: '日志编号',
            dataIndex: 'id',
            key: 'id',
            align: 'center',
            width: 100,
        },
        {
            title: '日志类型',
            dataIndex: 'logType',
            key: 'logType',
            align: 'center',
            width: 100,
            render: (value, record) => (
                value === 100 ? <Tag color="purple"> 账号登陆 </Tag> : <Tag color='yellow'> 退出登陆</Tag>
            )
        },
        {
            title: '用户名称',
            dataIndex: 'username',
            key: 'username',
            align: 'center',
            width: 150,
        },
        {
            title: '登录地址',
            dataIndex: 'userIp',
            key: 'userIp',
            align: 'center',
            width: 150,
        },
        {
            title: '浏览器',
            dataIndex: 'userAgent',
            key: 'userIp',
            align: 'center',
            width: 300,
            render: (text, record) => (
                <Tooltip title={text}>
                    <div className='text-ellipsis overflow-hidden whitespace-nowrap max-w-xs'>
                        {text}
                    </div>
                </Tooltip>
            )
        },
        {
            title: '登陆结果',
            dataIndex: 'result',
            key: 'result',
            align: 'center',
            width: 100,
        },
        {
            title: '登录日期',
            key: 'createTime',
            dataIndex: 'createTime',
            width: 200,
            align: 'center',
            render: (value: number) => {
                return formatDate(new Date(value), "YYYY-mm-dd HH:MM:SS")
            }
        },
        {
            title: t("QkOmYwne" /* 操作 */),
            key: 'action',
            fixed: 'right',
            align: 'center',
            width: 100,
            render: (value: LoginLogVO, record) => (
                <Space size="small" split={(<Divider type='vertical' />)}>
                    <a onClick={() => {

                    }}>
                        详情
                    </a>
                </Space>
            ),
        },
    ];

    useEffect(() => {
        load();
    }, [searchState]);

    const onChange: TableProps<LoginLogVO>['onChange'] = (pagination, filters, sorter, extra) => {
        const state: LoginLogReqVO = {
            // title: filters.title ? filters.title[0] as string : undefined,
            // status: filters.status ? filters.status[0] as number : undefined,
            pageNo: pagination.current,
            pageSize: pagination.pageSize
        }
        setOnSearching(true);
        setSearchState(state);
    };

    return (
        <>
            <div>
                <Card className='mt-[4px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]'>
                    <Table rowKey="id"
                        scroll={{ x: true }}
                        columns={columns}
                        dataSource={dataSource}
                        onChange={onChange}
                        className='bg-transparent'
                        pagination={{
                            position: ['bottomRight'],
                            current: searchState.pageNo,
                            pageSize: searchState.pageSize,
                            total
                        }}
                    />
                </Card>
                <FloatButton 
                    type='primary'
                    tooltip={<div>导出日志</div>} 
                    icon={<DownloadOutlined />}
                />
            </div>
        </>
    );
};
